<?php
use Tygh\Registry;

if (!defined('BOOTSTRAP')) { die('Access denied'); }

/**
 * Adds the "Sadadqa" payment processor to the list
 */
function fn_sadadqa_install()
{
    fn_sadadqa_uninstall();

    db_query("INSERT INTO ?:payment_processors ?e", array (
        'processor' => 'Pay with Credit/debit card (Sadad)',
        'processor_script' => 'sadadqa.php',
        'processor_template' => '',
        'admin_template' => 'sadadqa.tpl',
        'callback' => 'Y',
        'type' => 'P'
    ));
}

/**
 * Removes the "Sadadqa" payment processor from the list
 */
function fn_sadadqa_uninstall()
{
    db_query("DELETE FROM ?:payment_processors WHERE processor_script = ?s", 'sadadqa.php');
}

/**
 * Get sadadqa processor params
 *
 * @return array|string
 */
function fn_sadadqa_get_processor_params()
{
    $processor_params = db_get_field(
        'SELECT ?:payments.processor_params'
        . ' FROM ?:payments'
        . ' LEFT JOIN ?:payment_processors'
        . ' ON ?:payment_processors.processor_id = ?:payments.processor_id'
        . ' WHERE ?:payment_processors.processor_script = ?s'
        . ' AND ?:payments.status = ?s', SADADQA_PROCESSOR_SCRIPT, 'A'
    );

    return !empty($processor_params) ? unserialize($processor_params) : '';
}

function fn_get_baseurl_backend($withWw = 0)
{
	
    return fn_url();
}

/**
 * Hook.
 * This hook is needed for sadadqa calculator on the checkout page.
 * Changes params to get payment processors.
 *
 * @param array $params    Array of flags/data which determines which data should be gathered
 * @param array $fields    List of fields for retrieving
 * @param array $join      Array with the complete JOIN information (JOIN type, tables and fields) for an SQL-query
 * @param array $order     Array containing SQL-query with sorting fields
 * @param array $condition Array containing SQL-query condition possibly prepended with a logical operator AND
 * @param array $having    Array containing SQL-query condition to HAVING group
 */
function fn_sadadqa_get_payments($params, $fields, $join, $order, &$condition, $having)
{
    $mode = Registry::get('runtime.mode');

    if (($mode == 'checkout' || $mode == 'add') && !empty(Tygh::$app['session']['cart'])) {

        $processor_params = fn_sadadqa_get_processor_params();
        $cart = Tygh::$app['session']['cart'];

        if (!empty($cart['user_data']) && !empty($processor_params['currency'])) {

            if (!empty($cart['user_data']['user_id'])) {
                $cart['user_data'] = fn_get_user_info($cart['user_data']['user_id'], true);
            }
        }
    }
}